@@ -44,11 +44,11 @@ class ImageDataset(DatasetBase):
         if memmap_directory is None:
             print("- stored in RAM")
         else:
-            print("- stored on disk a {}".format(self.memmap_file))
+            print("- stored on disk at {}".format(self.memmap_file))
 
         if img_size is None:
             # Read first image to see the size
-            im = skio.imread(self.filenames[0], plugin='pil')
+            im = skio.imread(self.filenames[0])
             if self.transform_args is not None:
                 im = self.transform_fn(im, *self.transform_args)
             else:
@@ -67,7 +67,7 @@ class ImageDataset(DatasetBase):
                                          transform_args=self.transform_args)
             loader.load()
 
-    def create_generator(self, batch_size, idxs=None, map_fn=TFGenerator.map_fn_divide_255, shuffle=True, one_shot=False):
+    def create_generator(self, batch_size, idxs=None, map_fn=TFGenerator.map_fn_divide_255, shuffle=True, one_shot=False, undersample=False):
         # Create generators for training
         gen = TFGenerator(self.data,
                           self.cls,
@@ -75,5 +75,6 @@ class ImageDataset(DatasetBase):
                           batch_size=batch_size,
                           map_fn=map_fn,
                           shuffle=shuffle,
-                          one_shot=one_shot)
+                          one_shot=one_shot,
+                          undersample=undersample)
         return gen
