@@ -16,7 +16,7 @@ def work(producer_queue, consumer_queue, transform_fn, transform_args):
         if res is None:
             consumer_queue.put(None)
             break
-        im = skio.imread(res[1], plugin='pil')
+        im = skio.imread(res[1])
         if transform_fn is not None:
             if transform_args is not None:
                 im = transform_fn(im, *transform_args)
@@ -38,7 +38,7 @@ def consume(consumer_queue, array, multiplier, num_workers):
 
 
 def get_array_shape(filenames):
-    im = skio.imread(filenames[0], plugin='pil')
+    im = skio.imread(filenames[0])
     return (len(filenames),) + im.shape
 
 
@@ -75,18 +75,3 @@ class ParallelImageLoader:
         self.producer_queue.close()
         self.consumer_queue.close()
 
-
-if __name__ == "__main__":
-    from mml.data.filenames_dataset import FilenamesDataset
-
-    fs = FilenamesDataset(r"C:\data\SeagrassFrames")
-    fs.split(0.05)
-
-    shape = get_array_shape(fs.test_filenames)
-    print("Array shape is {}".format(shape))
-
-    from numpy.lib.format import open_memmap
-
-    mmap = open_memmap(r"D:\temp\test.npy", mode='w+', dtype=np.int8, shape=shape)
-    loader = ParallelImageLoader(fs.test_filenames, mmap)
-    loader.load()
