@@ -12,14 +12,14 @@ def load_image(filename, img_size=None, img_type='rgb'):
     """
     # Colour
     if img_type == 'rgb':
-        im = skio.imread(filename, plugin='pil')
+        im = skio.imread(filename)
         # im = np.asarray(im, dtype=np.float)
         # If it was a single channel image, make into 3-channel
         if im.ndim == 2:
             im = np.repeat(im[..., np.newaxis], repeats=3, axis=-1)
     # Greyscale
     elif img_type == 'k' or img_type == 'greyscale':
-        im = skio.imread(filename, as_gray=True, plugin='pil')
+        im = skio.imread(filename, as_gray=True)
         im = im[..., np.newaxis]
     else:
         raise ValueError("img_type must be 'rgb' or 'k'")
@@ -30,8 +30,6 @@ def load_image(filename, img_size=None, img_type='rgb'):
 
 
 def resize_and_pad_image(im, img_size):
-    print(im.shape)
-    print(img_size)
     # Add last dim if greyscale
     if np.ndim(im) == 2:
         im = im[..., np.newaxis]
@@ -89,7 +87,7 @@ def to_channels(im, out_channels, to_greyscale=False):
         img_channels = 1
     # Repeat if needed
     if img_channels == 1 and out_channels == 3:
-        im = np.repeat(im[..., np.newaxis], 3, axis=-1)
+        im = np.repeat(im, 3, axis=-1)
     return im
 
 
