@@ -1,8 +1,9 @@
 """
 Creates and trains a generic network
 """
+import os
+import skimage.io
 import warnings
-
 warnings.simplefilter(action='ignore', category=FutureWarning)
 
 import time
@@ -28,6 +29,17 @@ import matplotlib.pyplot as plt
 import pandas as pd
 
 
+def predict_in_batches(model, generator):
+    results = []
+    try:
+        for x, y in iter(generator):
+            results.append(model.predict(x))
+    except tf.errors.OutOfRangeError:
+        pass
+    results = np.concatenate(results, axis=0)
+    return results
+
+
 def train_image_classification_model(tp: MisoParameters):
     tf_version = int(tf.__version__[0])
 
@@ -76,6 +88,11 @@ def train_image_classification_model(tp: MisoParameters):
     ds.load()
     tp.dataset.num_classes = ds.num_classes
 
+    # Create save lodations
+    now = datetime.datetime.now()
+    save_dir = os.path.join(tp.output.save_dir, "{0}_{1:%Y%m%d-%H%M%S}".format(tp.name, now))
+    os.makedirs(save_dir, exist_ok=True)
+
     # ------------------------------------------------------------------------------
     # Transfer learning
     # ------------------------------------------------------------------------------
@@ -90,11 +107,11 @@ def train_image_classification_model(tp: MisoParameters):
         # Calculate vectors
         print("- calculating vectors")
         t = time.time()
-        gen = ds.images.create_generator(32, shuffle=False, one_shot=True)
+        gen = ds.images.create_generator(tp.training.batch_size, shuffle=False, one_shot=True)
         if tf_version == 2:
             vectors = model_head.predict(gen.create())
         else:
-            vectors = model_head.predict_generator(gen.create(), steps=len(gen))
+            vectors = predict_in_batches(model_head, gen.create())
         print("! {}s elapsed, ({}/{} vectors)".format(time.time() - t, len(vectors), len(ds.images.data)))
 
         # Clear session
@@ -118,7 +135,7 @@ def train_image_classification_model(tp: MisoParameters):
                                 tp.training.batch_size,
                                 shuffle=True,
                                 one_shot=False,
-                                oversample=tp.training.use_class_undersampling)
+                                undersample=tp.training.use_class_undersampling)
 
         # Validation generator
         if tf_version == 2:
@@ -145,10 +162,10 @@ def train_image_classification_model(tp: MisoParameters):
         else:
             class_weights = None
         if tp.training.use_class_undersampling:
-            print("- class balancing using random over sampling")
+            print("- class balancing using random under sampling")
 
-        v = model_tail.predict(vectors[0:1])
-        print(v[0, :10])
+        # v = model_tail.predict(vectors[0:1])
+        # print(v[0, :10])
 
         # model_head.summary()
 
@@ -218,15 +235,16 @@ def train_image_classification_model(tp: MisoParameters):
 
         # Generate model
         model = generate(tp)
+        model.summary()
 
         # Augmentation
         if tp.augmentation.rotation is True:
-            rotation_range = [0, 360]
-        else:
-            rotation_range = None
+            tp.augmentation.rotation = [0, 360]
+        elif tp.augmentation.rotation is False:
+            tp.augmentation.rotation = None
         if tp.training.use_augmentation is True:
             print("- using augmentation")
-            augment_fn = aug_all_fn(rotation=rotation_range,
+            augment_fn = aug_all_fn(rotation=tp.augmentation.rotation,
                                     gain=tp.augmentation.gain,
                                     gamma=tp.augmentation.gamma,
                                     zoom=tp.augmentation.zoom,
@@ -244,7 +262,19 @@ def train_image_classification_model(tp: MisoParameters):
                                                verbose=1)
 
         # Training generator
-        train_gen = ds.images.create_generator(tp.training.batch_size, map_fn=augment_fn)
+        train_gen = ds.train_generator(batch_size=tp.training.batch_size,
+                                       map_fn=augment_fn,
+                                       undersample=tp.training.use_class_undersampling)
+
+        # Save example of training data
+        print(" - saving example training batch")
+        training_examples_dir = os.path.join(save_dir, "examples", "training")
+        os.makedirs(training_examples_dir)
+        images, labels = next(iter(train_gen.create()))
+        for t_idx, im in enumerate(images):
+            im = (im * 255)
+            im[im > 255] = 255
+            skimage.io.imsave(os.path.join(training_examples_dir, "{:03d}.jpg".format(t_idx)), im.astype(np.uint8))
 
         # Validation generator
         if tf_version == 2:
@@ -253,7 +283,9 @@ def train_image_classification_model(tp: MisoParameters):
             # One repeat for validation for TF1 otherwise we get end of dataset errors
             val_one_shot = False
         if tp.dataset.val_split > 0:
-            val_gen = ds.test_generator(tp.training.batch_size, shuffle=False, one_shot=val_one_shot)
+            # Maximum 8 in batch otherwise validation results jump around a bit because
+            val_gen = ds.test_generator(min(tp.training.batch_size, 16), shuffle=False, one_shot=val_one_shot)
+            # val_gen = ds.test_generator(tp.training.batch_size, shuffle=False, one_shot=val_one_shot)
         else:
             val_gen = None
 
@@ -265,6 +297,8 @@ def train_image_classification_model(tp: MisoParameters):
                 class_weights = dict(enumerate(class_weights))
         else:
             class_weights = None
+        if tp.training.use_class_undersampling:
+            print("- class balancing using random under sampling")
 
         # Train the model
         history = model.fit_generator(train_gen.create(),
@@ -293,17 +327,14 @@ def train_image_classification_model(tp: MisoParameters):
     # ------------------------------------------------------------------------------
     print('-' * 80)
     print("Evaluating model")
-    now = datetime.datetime.now()
-    save_dir = os.path.join(tp.output.save_dir, "{0}_{1:%Y%m%d-%H%M%S}".format(tp.name, now))
-    os.makedirs(save_dir, exist_ok=True)
     # Accuracy
     if tp.dataset.val_split > 0:
         y_true = ds.cls[ds.test_idx]
-        gen = ds.test_generator(1, shuffle=False, one_shot=True)
+        gen = ds.test_generator(tp.training.batch_size, shuffle=False, one_shot=True)
         if tf_version == 2:
-            y_prob = model.predict(gen.to_tfdataset())
+            y_prob = model.predict(gen.create())
         else:
-            y_prob = model.predict_generator(gen.tf1_compat_generator(), len(gen))
+            y_prob = predict_in_batches(model, gen.create())
         y_pred = y_prob.argmax(axis=1)
     else:
         y_true = np.asarray([])
@@ -314,12 +345,12 @@ def train_image_classification_model(tp: MisoParameters):
     max_count = np.min([128, len(ds.images.data)])
     inf_times = []
     for i in range(3):
-        gen = ds.images.create_generator(32, idxs=np.arange(max_count), shuffle=False, one_shot=True)
+        gen = ds.images.create_generator(tp.training.batch_size, idxs=np.arange(max_count), shuffle=False, one_shot=True)
         start = time.time()
         if tf_version == 2:
-            model.predict(gen.to_tfdataset())
+            model.predict(gen.create())
         else:
-            model.predict_generator(gen.tf1_compat_generator(), len(gen))
+            predict_in_batches(model, gen.create())
         end = time.time()
         diff = (end - start) / max_count * 1000
         inf_times.append(diff)
@@ -407,15 +438,12 @@ def train_image_classification_model(tp: MisoParameters):
 
     # Vectors for mislabeled and t-SNE
     print("- calculating vectors... ", end='')
-    gen = ds.images.create_generator(1, shuffle=False, one_shot=True)
+    gen = ds.images.create_generator(tp.training.batch_size, shuffle=False, one_shot=True)
     if tf_version == 2:
-        vectors = vector_model.predict(gen.create(), steps=len(gen))
+        vectors = vector_model.predict(gen.create())
     else:
-        vectors = vector_model.predict_generator(gen.create(), steps=len(gen))
+        vectors = predict_in_batches(vector_model, gen.create())
     print("{} total".format(len(vectors)))
-    # print(vectors[0, :10])
-    v = vector_model.predict(ds.images.data[0:1] / 255)
-    # print(v[0, :10])
     if tp.output.save_mislabeled is True:
         print("- mislabeled")
         find_and_save_mislabelled(ds.images.data,
